@@ -21,15 +21,16 @@ import java.util.Arrays;
 
 /**
  * <p>Histogram for tracking the frequency of observations of values below interval upper bounds.</p>
- * <p>
+ *
  * <p>This class is useful for recording timings across a large number of observations
- * when high performance is required.<p>
- * <p>
+ * when high performance is required.</p>
+ *
  * <p>The interval bounds are used to define the ranges of the histogram buckets. If provided bounds
  * are [10,20,30,40,50] then there will be five buckets, accessible by index 0-4. Any value
  * 0-10 will fall into the first interval bar, values 11-20 will fall into the
  * second bar, and so on.</p>
  */
+@Deprecated
 public final class Histogram
 {
     // tracks the upper intervals of each of the buckets/bars
@@ -171,7 +172,7 @@ public final class Histogram
 
     /**
      * <p>Add observations from another Histogram into this one.</p>
-     * <p>
+     *
      * <p>Histograms must have the same intervals.</p>
      *
      * @param histogram from which to add the observation counts.
@@ -257,7 +258,7 @@ public final class Histogram
 
     /**
      * <p>Calculate the mean of all recorded observations.</p>
-     * <p>
+     *
      * <p>The mean is calculated by summing the mid points of each interval multiplied by the count
      * for that interval, then dividing by the total count of observations.  The max and min are
      * considered for adjusting the top and bottom bin when calculating the mid point, this
@@ -322,7 +323,7 @@ public final class Histogram
 
     /**
      * <p>Get the interval upper bound for a given factor of the observation population.</p>
-     * <p>
+     *
      * <p>Note this does not get the actual percentile measurement, it only gets the bucket</p>
      *
      * @param factor representing the size of the population.
