@@ -22,17 +22,20 @@ import java.util.*;
 /**
  * Provides a repository mechanism to associate {@link EventHandler}s with {@link EventProcessor}s
  *
- * @param T the type of the {@link EventHandler}
+ * @param <T> the type of the {@link EventHandler}
  */
 class ConsumerRepository<T> implements Iterable<ConsumerInfo>
 {
-    private final Map<EventHandler<?>, EventProcessorInfo<T>> eventProcessorInfoByEventHandler = new IdentityHashMap<EventHandler<?>, EventProcessorInfo<T>>();
-    private final Map<Sequence, ConsumerInfo> eventProcessorInfoBySequence = new IdentityHashMap<Sequence, ConsumerInfo>();
+    private final Map<EventHandler<?>, EventProcessorInfo<T>> eventProcessorInfoByEventHandler =
+        new IdentityHashMap<EventHandler<?>, EventProcessorInfo<T>>();
+    private final Map<Sequence, ConsumerInfo> eventProcessorInfoBySequence =
+        new IdentityHashMap<Sequence, ConsumerInfo>();
     private final Collection<ConsumerInfo> consumerInfos = new ArrayList<ConsumerInfo>();
 
-    public void add(final EventProcessor eventprocessor,
-                    final EventHandler<? super T> handler,
-                    final SequenceBarrier barrier)
+    public void add(
+        final EventProcessor eventprocessor,
+        final EventHandler<? super T> handler,
+        final SequenceBarrier barrier)
     {
         final EventProcessorInfo<T> consumerInfo = new EventProcessorInfo<T>(eventprocessor, handler, barrier);
         eventProcessorInfoByEventHandler.put(handler, consumerInfo);
@@ -74,7 +77,7 @@ class ConsumerRepository<T> implements Iterable<ConsumerInfo>
 
     public EventProcessor getEventProcessorFor(final EventHandler<T> handler)
     {
-        final EventProcessorInfo<?> eventprocessorInfo = getEventProcessorInfo(handler);
+        final EventProcessorInfo<T> eventprocessorInfo = getEventProcessorInfo(handler);
         if (eventprocessorInfo == null)
         {
             throw new IllegalArgumentException("The event handler " + handler + " is not processing events.");
