@@ -21,6 +21,8 @@ import com.lmax.disruptor.EventHandler;
 import com.lmax.disruptor.EventProcessor;
 import com.lmax.disruptor.EventTranslator;
 import com.lmax.disruptor.EventTranslatorOneArg;
+import com.lmax.disruptor.EventTranslatorThreeArg;
+import com.lmax.disruptor.EventTranslatorTwoArg;
 import com.lmax.disruptor.ExceptionHandler;
 import com.lmax.disruptor.RingBuffer;
 import com.lmax.disruptor.Sequence;
@@ -37,14 +39,11 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 /**
- * A DSL-style API for setting up the disruptor pattern around a ring buffer
- * (aka the Builder pattern).
- * <p>
- * <p>
- * A simple example of setting up the disruptor with two event handlers that
- * must process events in order:
- * </p>
- * <p>
+ * <p>A DSL-style API for setting up the disruptor pattern around a ring buffer
+ * (aka the Builder pattern).</p>
+ *
+ * <p>A simple example of setting up the disruptor with two event handlers that
+ * must process events in order:</p>
  * <pre>
  * <code>Disruptor&lt;MyEvent&gt; disruptor = new Disruptor&lt;MyEvent&gt;(MyEvent.FACTORY, 32, Executors.newCachedThreadPool());
  * EventHandler&lt;MyEvent&gt; handler1 = new EventHandler&lt;MyEvent&gt;() { ... };
@@ -134,9 +133,9 @@ public class Disruptor<T>
             final ProducerType producerType,
             final WaitStrategy waitStrategy)
     {
-        this(RingBuffer.create(
-                               producerType, eventFactory, ringBufferSize, waitStrategy),
-                new BasicExecutor(threadFactory));
+        this(
+            RingBuffer.create(producerType, eventFactory, ringBufferSize, waitStrategy),
+            new BasicExecutor(threadFactory));
     }
 
     /**
@@ -151,7 +150,7 @@ public class Disruptor<T>
     /**
      * <p>Set up event handlers to handle events from the ring buffer. These handlers will process events
      * as soon as they become available, in parallel.</p>
-     * <p>
+     *
      * <p>This method can be used as the start of a chain. For example if the handler <code>A</code> must
      * process events before handler <code>B</code>:</p>
      * <pre><code>dw.handleEventsWith(A).then(B);</code></pre>
@@ -168,11 +167,11 @@ public class Disruptor<T>
     /**
      * <p>Set up custom event processors to handle events from the ring buffer. The Disruptor will
      * automatically start these processors when {@link #start()} is called.</p>
-     * <p>
+     *
      * <p>This method can be used as the start of a chain. For example if the handler <code>A</code> must
      * process events before handler <code>B</code>:</p>
      * <pre><code>dw.handleEventsWith(A).then(B);</code></pre>
-     * <p>
+     *
      * <p>Since this is the start of the chain, the processor factories will always be passed an empty <code>Sequence</code>
      * array, so the factory isn't necessary in this case. This method is provided for consistency with
      * {@link EventHandlerGroup#handleEventsWith(EventProcessorFactory...)} and {@link EventHandlerGroup#then(EventProcessorFactory...)}
@@ -190,7 +189,7 @@ public class Disruptor<T>
     /**
      * <p>Set up custom event processors to handle events from the ring buffer. The Disruptor will
      * automatically start this processors when {@link #start()} is called.</p>
-     * <p>
+     *
      * <p>This method can be used as the start of a chain. For example if the processor <code>A</code> must
      * process events before handler <code>B</code>:</p>
      * <pre><code>dw.handleEventsWith(A).then(B);</code></pre>
@@ -204,6 +203,15 @@ public class Disruptor<T>
         {
             consumerRepository.add(processor);
         }
+
+        final Sequence[] sequences = new Sequence[processors.length];
+        for (int i = 0; i < processors.length; i++)
+        {
+            sequences[i] = processors[i].getSequence();
+        }
+
+        ringBuffer.addGatingSequences(sequences);
+
         return new EventHandlerGroup<T>(this, consumerRepository, Util.getSequencesFor(processors));
     }
 
@@ -224,7 +232,7 @@ public class Disruptor<T>
 
     /**
      * <p>Specify an exception handler to be used for any future event handlers.</p>
-     * <p>
+     *
      * <p>Note that only event handlers set up after calling this method will use the exception handler.</p>
      *
      * @param exceptionHandler the exception handler to use for any future {@link EventProcessor}.
@@ -237,7 +245,7 @@ public class Disruptor<T>
 
     /**
      * <p>Specify an exception handler to be used for event handlers and worker pools created by this Disruptor.</p>
-     * <p>
+     *
      * <p>The exception handler will be used by existing and future event handlers and worker pools created by this Disruptor instance.</p>
      *
      * @param exceptionHandler the exception handler to use.
@@ -268,7 +276,7 @@ public class Disruptor<T>
     /**
      * <p>Create a group of event handlers to be used as a dependency.
      * For example if the handler <code>A</code> must process events before handler <code>B</code>:</p>
-     * <p>
+     *
      * <pre><code>dw.after(A).handleEventsWith(B);</code></pre>
      *
      * @param handlers the event handlers, previously set up with {@link #handleEventsWith(com.lmax.disruptor.EventHandler[])},
@@ -318,6 +326,7 @@ public class Disruptor<T>
     /**
      * Publish an event to the ring buffer.
      *
+     * @param <A> Class of the user supplied argument.
      * @param eventTranslator the translator that will load data into the event.
      * @param arg             A single argument to load into the event
      */
@@ -329,6 +338,7 @@ public class Disruptor<T>
     /**
      * Publish a batch of events to the ring buffer.
      *
+     * @param <A> Class of the user supplied argument.
      * @param eventTranslator the translator that will load data into the event.
      * @param arg             An array single arguments to load into the events. One Per event.
      */
@@ -337,21 +347,48 @@ public class Disruptor<T>
         ringBuffer.publishEvents(eventTranslator, arg);
     }
 
+    /**
+     * Publish an event to the ring buffer.
+     *
+     * @param <A> Class of the user supplied argument.
+     * @param <B> Class of the user supplied argument.
+     * @param eventTranslator the translator that will load data into the event.
+     * @param arg0            The first argument to load into the event
+     * @param arg1            The second argument to load into the event
+     */
+    public <A, B> void publishEvent(final EventTranslatorTwoArg<T, A, B> eventTranslator, final A arg0, final B arg1)
+    {
+        ringBuffer.publishEvent(eventTranslator, arg0, arg1);
+    }
+
+    /**
+     * Publish an event to the ring buffer.
+     *
+     * @param eventTranslator the translator that will load data into the event.
+     * @param <A> Class of the user supplied argument.
+     * @param <B> Class of the user supplied argument.
+     * @param <C> Class of the user supplied argument.
+     * @param arg0            The first argument to load into the event
+     * @param arg1            The second argument to load into the event
+     * @param arg2            The third argument to load into the event
+     */
+    public <A, B, C> void publishEvent(final EventTranslatorThreeArg<T, A, B, C> eventTranslator, final A arg0, final B arg1, final C arg2)
+    {
+        ringBuffer.publishEvent(eventTranslator, arg0, arg1, arg2);
+    }
+
     /**
      * <p>Starts the event processors and returns the fully configured ring buffer.</p>
-     * <p>
+     *
      * <p>The ring buffer is set up to prevent overwriting any entry that is yet to
      * be processed by the slowest event processor.</p>
-     * <p>
+     *
      * <p>This method must only be called once after all event processors have been added.</p>
      *
      * @return the configured ring buffer.
      */
     public RingBuffer<T> start()
     {
-        final Sequence[] gatingSequences = consumerRepository.getLastSequenceInChain(true);
-        ringBuffer.addGatingSequences(gatingSequences);
-
         checkOnlyStartedOnce();
         for (final ConsumerInfo consumerInfo : consumerRepository)
         {
@@ -373,10 +410,10 @@ public class Disruptor<T>
     }
 
     /**
-     * Waits until all events currently in the disruptor have been processed by all event processors
+     * <p>Waits until all events currently in the disruptor have been processed by all event processors
      * and then halts the processors.  It is critical that publishing to the ring buffer has stopped
-     * before calling this method, otherwise it may never return.
-     * <p>
+     * before calling this method, otherwise it may never return.</p>
+     *
      * <p>This method will not shutdown the executor, nor will it await the final termination of the
      * processor threads.</p>
      */
@@ -395,12 +432,13 @@ public class Disruptor<T>
     /**
      * <p>Waits until all events currently in the disruptor have been processed by all event processors
      * and then halts the processors.</p>
-     * <p>
+     *
      * <p>This method will not shutdown the executor, nor will it await the final termination of the
      * processor threads.</p>
      *
      * @param timeout  the amount of time to wait for all events to be processed. <code>-1</code> will give an infinite timeout
      * @param timeUnit the unit the timeOut is specified in
+     * @throws TimeoutException if a timeout occurs before shutdown completes.
      */
     public void shutdown(final long timeout, final TimeUnit timeUnit) throws TimeoutException
     {
@@ -472,6 +510,17 @@ public class Disruptor<T>
         return consumerRepository.getBarrierFor(handler);
     }
 
+    /**
+     * Gets the sequence value for the specified event handlers.
+     *
+     * @param b1 eventHandler to get the sequence for.
+     * @return eventHandler's sequence
+     */
+    public long getSequenceValueFor(final EventHandler<T> b1)
+    {
+        return consumerRepository.getSequenceFor(b1).get();
+    }
+
     /**
      * Confirms if all messages have been consumed by all event processors
      */
@@ -513,14 +562,24 @@ public class Disruptor<T>
             processorSequences[i] = batchEventProcessor.getSequence();
         }
 
-        if (processorSequences.length > 0)
-        {
-            consumerRepository.unMarkEventProcessorsAsEndOfChain(barrierSequences);
-        }
+        updateGatingSequencesForNextInChain(barrierSequences, processorSequences);
 
         return new EventHandlerGroup<T>(this, consumerRepository, processorSequences);
     }
 
+    private void updateGatingSequencesForNextInChain(final Sequence[] barrierSequences, final Sequence[] processorSequences)
+    {
+        if (processorSequences.length > 0)
+        {
+            ringBuffer.addGatingSequences(processorSequences);
+            for (final Sequence barrierSequence : barrierSequences)
+            {
+                ringBuffer.removeGatingSequence(barrierSequence);
+            }
+            consumerRepository.unMarkEventProcessorsAsEndOfChain(barrierSequences);
+        }
+    }
+
     EventHandlerGroup<T> createEventProcessors(
         final Sequence[] barrierSequences, final EventProcessorFactory<T>[] processorFactories)
     {
@@ -529,6 +588,7 @@ public class Disruptor<T>
         {
             eventProcessors[i] = processorFactories[i].createEventProcessor(ringBuffer, barrierSequences);
         }
+
         return handleEventsWith(eventProcessors);
     }
 
@@ -537,8 +597,15 @@ public class Disruptor<T>
     {
         final SequenceBarrier sequenceBarrier = ringBuffer.newBarrier(barrierSequences);
         final WorkerPool<T> workerPool = new WorkerPool<T>(ringBuffer, sequenceBarrier, exceptionHandler, workHandlers);
+
+
         consumerRepository.add(workerPool, sequenceBarrier);
-        return new EventHandlerGroup<T>(this, consumerRepository, workerPool.getWorkerSequences());
+
+        final Sequence[] workerSequences = workerPool.getWorkerSequences();
+
+        updateGatingSequencesForNextInChain(barrierSequences, workerSequences);
+
+        return new EventHandlerGroup<T>(this, consumerRepository, workerSequences);
     }
 
     private void checkNotStarted()
