@@ -1240,13 +1240,13 @@ public class RingBufferTest
     }
 
     @Test
-    public void shouldHandleResetToAndNotWrapUnecessarilySingleProducer() throws Exception
+    public void shouldHandleResetToAndNotWrapUnnecessarilySingleProducer() throws Exception
     {
         assertHandleResetAndNotWrap(RingBuffer.createSingleProducer(StubEvent.EVENT_FACTORY, 4));
     }
 
     @Test
-    public void shouldHandleResetToAndNotWrapUnecessarilyMultiProducer() throws Exception
+    public void shouldHandleResetToAndNotWrapUnnecessarilyMultiProducer() throws Exception
     {
         assertHandleResetAndNotWrap(RingBuffer.createMultiProducer(StubEvent.EVENT_FACTORY, 4));
     }
@@ -1307,7 +1307,7 @@ public class RingBufferTest
         private final AtomicBoolean running = new AtomicBoolean();
 
 
-        public TestEventProcessor(final SequenceBarrier sequenceBarrier)
+        TestEventProcessor(final SequenceBarrier sequenceBarrier)
         {
             this.sequenceBarrier = sequenceBarrier;
         }
@@ -1354,7 +1354,7 @@ public class RingBufferTest
     {
         private final int size;
 
-        public ArrayFactory(int size)
+        ArrayFactory(int size)
         {
             this.size = size;
         }
