@@ -15,26 +15,18 @@
  */
 package com.lmax.disruptor.util;
 
-import static org.hamcrest.CoreMatchers.*;
-import static org.junit.Assert.assertThat;
+import com.lmax.disruptor.Sequence;
+import org.junit.Assert;
+import org.junit.Test;
 
 import java.nio.ByteBuffer;
 
-import org.jmock.Expectations;
-import org.jmock.Mockery;
-import org.jmock.integration.junit4.JMock;
-import org.jmock.lib.legacy.ClassImposteriser;
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
+import static org.hamcrest.CoreMatchers.is;
+import static org.hamcrest.CoreMatchers.not;
+import static org.junit.Assert.assertThat;
 
-import com.lmax.disruptor.Sequence;
-
-@RunWith(JMock.class)
 public final class UtilTest
 {
-    private final Mockery context = new Mockery();
-
     @Test
     public void shouldReturnNextPowerOfTwo()
     {
@@ -54,29 +46,7 @@ public final class UtilTest
     @Test
     public void shouldReturnMinimumSequence()
     {
-        final Sequence[] sequences = new Sequence[3];
-
-        context.setImposteriser(ClassImposteriser.INSTANCE);
-
-        sequences[0] = context.mock(Sequence.class, "s0");
-        sequences[1] = context.mock(Sequence.class, "s1");
-        sequences[2] = context.mock(Sequence.class, "s2");
-
-        context.checking(
-            new Expectations()
-            {
-                {
-                    oneOf(sequences[0]).get();
-                    will(returnValue(Long.valueOf(7L)));
-
-                    oneOf(sequences[1]).get();
-                    will(returnValue(Long.valueOf(3L)));
-
-                    oneOf(sequences[2]).get();
-                    will(returnValue(Long.valueOf(12L)));
-                }
-            });
-
+        final Sequence[] sequences = {new Sequence(7L), new Sequence(3L), new Sequence(12L)};
         Assert.assertEquals(3L, Util.getMinimumSequence(sequences));
     }
 
